@@ -2,7 +2,7 @@ package JAAS::Object;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use Carp;
 use Data::Denter;
@@ -95,7 +95,13 @@ sub _attach
     croak "No delegate" unless $delegate;
 
     # get the new methods
-    my %m=$delegate->methods;
+    my @m=$delegate->methods;
+    my %m;
+    if(scalar(@m) & 1) {
+        print STDERR "Bad return from $delegate\->methods\n";
+    } else {
+        %m=@m;
+    }
     my %methods;
     foreach my $method (keys %m) {
         croak "Please don't call your method $method" if $method=~ /^_/;
@@ -808,7 +814,8 @@ following:
 
 =head1 AUTHOR
 
-Philip Gwyn <perl at pied.nu>
+Philip Gwyn <jaas at awale.qc.ca>, 
+Learry Gagn <mou-jaas at awale.qc.ca>.
 
 =head1 SEE ALSO
 
