@@ -1,4 +1,4 @@
-# $Id: Relationships.pm,v 1.5 2001/09/18 19:57:17 fil Exp $
+# $Id: Relationships.pm,v 1.6 2002/06/07 08:32:12 fil Exp $
 package JAAS::Object::Relationships;
 
 use strict;
@@ -115,7 +115,10 @@ sub remove
     my($self, $who)=@_;
     $self=$jaas_relationships unless ref $self;
     my $nails=$self->{nails};
-
+    unless($who) {
+        carp "Use jaas_relationships->remove(\$who)";
+        return 0;
+    }
     my $n;
     if($nails->{$who}) {
         DEBUG and carp "Deleting $who";
@@ -513,7 +516,8 @@ Returns a string that shows all relationships that a given person is in.
 
 =head1 AUTHOR
 
-Philip Gwyn <perl at pied.nu>
+Philip Gwyn <jaas at awale.qc.ca>, 
+Learry Gagn <mou-jaas at awale.qc.ca>.
 
 =head1 SEE ALSO
 
@@ -523,6 +527,10 @@ perl(1).
 
 
 $Log: Relationships.pm,v $
+Revision 1.6  2002/06/07 08:32:12  fil
+Check a delegates methods() return to make sure it's a hash
+More error checking in Relationship::remove
+
 Revision 1.5  2001/09/18 19:57:17  fil
 Added the OOB feature
 
